==> haskell-css-text-0.1.3.0-114-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-css-text.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 css-text
version:              0.1.3.0
visibility:           public
id:                   css-text-0.1.3.0-H9Rgkcaieoi7AMdhzcu0n9
key:                  css-text-0.1.3.0-H9Rgkcaieoi7AMdhzcu0n9
license:              MIT
maintainer:
    Michael Snoyman <michael@snoyman.com>, Greg Weber <greg@gregweber.info>

author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             https://github.com/yesodweb/css-text.git#readme
synopsis:             CSS parser and renderer.
description:
    Please see the README and generated docs at <https://www.stackage.org/package/css-text>

category:             Web, Yesod
abi:                  0a8594012c0b251aabc091e6ba954a3d
exposed:              True
exposed-modules:      Text.CSS.Parse Text.CSS.Render
hidden-modules:       Paths_css_text
import-dirs:          /usr/lib/ghc-8.10.2/site-local/css-text-0.1.3.0
library-dirs:         /usr/lib/ghc-8.10.2/site-local/css-text-0.1.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/css-text-0.1.3.0
hs-libraries:         HScss-text-0.1.3.0-H9Rgkcaieoi7AMdhzcu0n9
depends:
    attoparsec-0.13.2.4-BkYo3BeI9ab9OAiwbGneKH base-4.14.1.0
    text-1.2.3.2

haddock-interfaces:   /usr/share/doc/haskell-css-text/html/css-text.haddock
haddock-html:         /usr/share/doc/haskell-css-text/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-css-text-0.1.3.0-116-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-css-text.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 css-text
version:              0.1.3.0
visibility:           public
id:                   css-text-0.1.3.0-EaE5xqazXuBBrpbIBW3ZuE
key:                  css-text-0.1.3.0-EaE5xqazXuBBrpbIBW3ZuE
license:              MIT
maintainer:
    Michael Snoyman <michael@snoyman.com>, Greg Weber <greg@gregweber.info>

author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             https://github.com/yesodweb/css-text.git#readme
synopsis:             CSS parser and renderer.
description:
    Please see the README and generated docs at <https://www.stackage.org/package/css-text>

category:             Web, Yesod
abi:                  5c1ab12165f93d954858780de8931919
exposed:              True
exposed-modules:      Text.CSS.Parse Text.CSS.Render
hidden-modules:       Paths_css_text
import-dirs:          /usr/lib/ghc-8.10.2/site-local/css-text-0.1.3.0
library-dirs:         /usr/lib/ghc-8.10.2/site-local/css-text-0.1.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/css-text-0.1.3.0
hs-libraries:         HScss-text-0.1.3.0-EaE5xqazXuBBrpbIBW3ZuE
depends:
    attoparsec-0.13.2.4-A3iUKuJR7UBHxmP0AEJfvQ base-4.14.1.0
    text-1.2.3.2

haddock-interfaces:   /usr/share/doc/haskell-css-text/html/css-text.haddock
haddock-html:         /usr/share/doc/haskell-css-text/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
